@@ -1,7 +1,9 @@
 # Copyright (C) 2007-2011 Andrea Francia Trivolzio(PV) Italy
 from __future__ import absolute_import
 
-version = '0.21.5.25'
+import datetime
+
+version = '0.21.6.10.1'
 
 import os
 import logging
@@ -51,67 +53,6 @@ def volume_trash_dir2(volume, getuid):
     yield path, volume
 
 
-def do_nothing(*argv, **argvk): pass
-class Parser:
-    def __init__(self):
-        self.default_action = do_nothing
-        self.argument_action = do_nothing
-        self.short_options = ''
-        self.long_options = []
-        self.actions = dict()
-        self._on_invalid_option = do_nothing
-
-    def __call__(self, argv):
-        program_name = argv[0]
-        from getopt import getopt, GetoptError
-
-        try:
-            options, arguments = getopt(argv[1:],
-                                        self.short_options,
-                                        self.long_options)
-        except GetoptError as e:
-            invalid_option = e.opt
-            self._on_invalid_option(program_name, invalid_option)
-        else:
-            for option, value in options:
-                if option in ('--help', '-h', '--version'):
-                    self.actions[option](program_name)
-                    return
-                if option in self.actions:
-                    self.actions[option](value)
-                    return
-            for argument in arguments:
-                self.argument_action(argument)
-            self.default_action()
-
-    def on_invalid_option(self, action):
-        self._on_invalid_option = action
-
-    def on_help(self, action):
-        self.add_option('help', action, 'h')
-
-    def on_version(self, action):
-        self.add_option('version', action)
-
-    def add_option(self, long_option, action, short_aliases=''):
-        self.long_options.append(long_option)
-        if long_option.endswith('='):
-            import re
-            long_option = re.sub('=$', '', long_option)
-        self.actions['--' + long_option] = action
-        for short_alias in short_aliases:
-            self.add_short_option(short_alias, action)
-
-    def add_short_option(self, short_option, action):
-        self.short_options += short_option
-        self.actions['-' + short_option] = action
-
-    def on_argument(self, argument_action):
-        self.argument_action = argument_action
-    def as_default(self, default_action):
-        self.default_action = default_action
-
-
 class MyEnum:
     def __init__(self, name):
         self.name = name
@@ -183,12 +124,10 @@ class PrintHelp:
     def my_print_help(self, program_name):
         self.description(program_name, self.printer)
 
-class PrintVersion:
-    def __init__(self, out, version):
-        self.out = out
-        self.version = version
-    def print_version(self, program_name):
-        println(self.out, "%s %s" % (program_name, self.version))
+
+def print_version(out, program_name, version):
+    println(out, "%s %s" % (program_name, version))
+
 
 class TopTrashDirValidationResult:
     class DoesNotExist:
@@ -254,6 +193,10 @@ try:
 except ImportError:
     from urllib.parse import unquote
 
+
+def do_nothing(*argv, **argvk): pass
+
+
 class ParseTrashInfo:
     def __init__(self,
                  on_deletion_date = do_nothing,
@@ -294,3 +237,18 @@ def parse_path(contents):
     raise ParseError('Unable to parse Path')
 
 
+class Clock:
+    def __init__(self, real_now, environ):
+        self.real_now = real_now
+        self.environ = environ
+
+    def get_now_value(self, errors):
+        if 'TRASH_DATE' in self.environ:
+            try:
+                return datetime.datetime.strptime(self.environ['TRASH_DATE'],
+                                                  "%Y-%m-%dT%H:%M:%S")
+            except ValueError:
+                errors.print_error('invalid TRASH_DATE: %s' %
+                                   self.environ['TRASH_DATE'])
+                return self.real_now()
+        return self.real_now()
